==> openGion7.0.3.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE15S.sql <==
/****************************************************************************/
/* GE15 ( ｱｸｾｽ調査ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:39                                            */
/****************************************************************************/

CREATE TABLE GE15 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID               */
 , USERID           varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID              */
 , USERADRS         varchar           (   40 )                                      /*  30 IPｱﾄﾞﾚｽ(local)       */
 , HOSTADRS         varchar           (   40 )                                      /*  40 IPｱﾄﾞﾚｽ(remote)      */
 , GUIKEY           varchar           (   30 )                                      /*  50 画面ID               */
 , DYLOGIN          varchar           (   14 )                                      /*  60 ﾛｸﾞｲﾝ時間            */
 , DYLOGOUT         varchar           (   14 )                                      /*  70 ﾛｸﾞｱｳﾄ時間           */
 , USED_TIME        INTEGER                         DEFAULT 0   NOT NULL            /*  80 使用時間(秒)         */
 , CNT_ACCESS       INTEGER                         DEFAULT 0   NOT NULL            /*  90 ｱｸｾｽ件数             */
 , CNT_ERROR        INTEGER                         DEFAULT 0   NOT NULL            /* 100 ｴﾗｰ件数              */
 , CNT_READ         INTEGER                         DEFAULT 0   NOT NULL            /* 110 読込件数             */
 , CNT_WRITE        INTEGER                         DEFAULT 0   NOT NULL            /* 120 出力件数             */
 , TM_TOTAL_QUERY   float                           DEFAULT 0   NOT NULL            /* 130 ﾄｰﾀﾙDBｸｴﾘ時間(ms)    */
 , TM_MAX_QUERY     INTEGER                         DEFAULT 0   NOT NULL            /* 140 最大DBｸｴﾘ時間(ms)    */
 , MAX_QUERY        varchar           ( 4000 )                                      /* 150 最長実行ｸｴﾘ          */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時             */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG               */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG             */
 , USRSET           varchar           (   10 )                                      /* 850 作成者               */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時             */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG               */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG             */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者               */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE15S.sql <==
/****************************************************************************/
/* GE15 ( ｱｸｾｽ調査ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE15 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID               */
 , USERID           varchar           (   10 )                  NOT NULL            /*  20 ﾕｰｻﾞｰID              */
 , USERADRS         varchar           (   40 )                                      /*  30 IPｱﾄﾞﾚｽ(local)       */
 , HOSTADRS         varchar           (   40 )                                      /*  40 IPｱﾄﾞﾚｽ(remote)      */
 , GUIKEY           varchar           (   30 )                                      /*  50 画面ID               */
 , DYLOGIN          varchar           (   14 )                                      /*  60 ﾛｸﾞｲﾝ時間            */
 , DYLOGOUT         varchar           (   14 )                                      /*  70 ﾛｸﾞｱｳﾄ時間           */
 , USED_TIME        INTEGER                         DEFAULT 0   NOT NULL            /*  80 使用時間(秒)         */
 , CNT_ACCESS       INTEGER                         DEFAULT 0   NOT NULL            /*  90 ｱｸｾｽ件数             */
 , CNT_ERROR        INTEGER                         DEFAULT 0   NOT NULL            /* 100 ｴﾗｰ件数              */
 , CNT_READ         INTEGER                         DEFAULT 0   NOT NULL            /* 110 読込件数             */
 , CNT_WRITE        INTEGER                         DEFAULT 0   NOT NULL            /* 120 出力件数             */
 , TM_TOTAL_QUERY   float                           DEFAULT 0   NOT NULL            /* 130 ﾄｰﾀﾙDBｸｴﾘ時間(ms)    */
 , TM_MAX_QUERY     INTEGER                         DEFAULT 0   NOT NULL            /* 140 最大DBｸｴﾘ時間(ms)    */
 , MAX_QUERY        varchar           ( 4000 )                                      /* 150 最長実行ｸｴﾘ          */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            varchar           (   14 )                                      /* 820 作成日時             */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG               */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG             */
 , USRSET           varchar           (   10 )                                      /* 850 作成者               */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時             */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG               */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG             */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者               */
);
